@@ -15,12 +15,14 @@ class NetEaseStatistics(Statistics):
                 "recall": {},
                 "precision": {},
                 "f1": {},
+                "reject_rate": {}
             },
             "review2reject": {
                 "accuracy": tuple(),
                 "recall": {},
                 "precision": {},
                 "f1": {},
+                "reject_rate": {}
             }
         }
 
@@ -51,6 +53,12 @@ class NetEaseStatistics(Statistics):
             self.indicator["review2reject"]["precision"][mode] = self.precision(self.df_review2reject, "type",
                                                                                 "predict_type", mode)
 
+    def count_reject_rate(self, mode: str = "政治"):
+        self.indicator["review2pass"]["reject_rate"][mode] = self.reject_rate(self.df_review2pass, "type",
+                                                                            "predict_label", mode)
+        self.indicator["review2reject"]["reject_rate"][mode] = self.reject_rate(self.df_review2reject, "type",
+                                                                              "predict_label", mode)
+
     def __count_f1(self):
         for category in self.indicator["review2pass"]["precision"]:
             self.indicator["review2pass"]["f1"][category] = self.f1(
@@ -65,6 +73,8 @@ class NetEaseStatistics(Statistics):
         for _type in ["整体", "政治"] + other_type:
             self.count_recall(_type)
             self.count_precision(_type)
+            if _type != "整体":
+                self.count_reject_rate(_type)
         self.__count_f1()
 
     def parse_standard_and_result(self, standard_file: str, result_file: str):
