@@ -1,13 +1,7 @@
 from whisper_evaluate import WhisperStatistics, NetEaseStatistics
+from whisper_evaluate.utils import logging
 import os
 import time
-import sys
-import logging
-
-logging.basicConfig(
-    format='%(asctime)s %(levelname)s %(message)s',
-    level=logging.INFO,
-    stream=sys.stdout)
 
 
 class Report(object):
