@@ -1,7 +1,11 @@
 from whisper_evaluate import Statistics
 import numpy as np
 import pandas as pd
+from pandarallel import pandarallel
 from whisper_evaluate.config import en_zh
+import json
+
+pandarallel.initialize()
 
 
 class WhisperStatistics(Statistics):
@@ -66,48 +70,79 @@ class WhisperStatistics(Statistics):
 
     def parse_standard_and_result(self, standard_file: str, result_file: str = None):
         standard_df = pd.read_csv(standard_file)
-        lines = None
         if result_file:
             standard_df.columns = ["example", "label", "type"]
             with open(result_file, 'r', encoding='utf-8') as f:
                 lines = f.readlines()
+            standard_df["result_json"] = pd.Series(lines)
         else:
             standard_df.columns = ["example", "label", "type", "result_json"]
-        self.__parse_result_json(standard_df, lines)
-
-    def __parse_result_json(self, standard_df: pd.DataFrame, _iter=None):
-        result = []
-        if _iter is None:
-            _iter = standard_df.result_json
-        for line in _iter:
-            a = eval(line)
-            results = a['results'][0]
-            _match_words = results['matched_words']
-            _new_words = results['new_words']
-            _review_words = results['review_words']
-            predict_type = self._get_result_type(_match_words + _new_words)
-            predict_label = "Pass" if predict_type == "其他" else "Reject"
-            predict_type_trie = "政治" if self._get_result_type(_review_words) == "政治" else predict_type
-            predict_label_trie = "Pass" if predict_type_trie == "其他" else "Reject"
-            result.append([predict_label, predict_type, predict_label_trie, predict_type_trie,
-                           " ".join([x["word"] for x in _match_words]), " ".join([x["word"] for x in _new_words]),
-                           " ".join([x["word"] for x in _review_words])])
-
-        result = np.array(result)
-        if 'res_json' in standard_df.columns:
-            standard_df.drop(columns=['res_json'])
-        standard_df["predict_label"] = pd.Series(result[:, 0])
-        standard_df["predict_type"] = pd.Series(result[:, 1])
-        standard_df["predict_label_trie"] = pd.Series(result[:, 2])
-        standard_df["predict_type_trie"] = pd.Series(result[:, 3])
-        standard_df["match_words"] = pd.Series(result[:, 4])
-        standard_df["new_words"] = pd.Series(result[:, 5])
-        standard_df["review_words"] = pd.Series(result[:, 6])
+        (standard_df["predict_label"],
+         standard_df["predict_type"],
+         standard_df["predict_label_trie"],
+         standard_df["predict_type_trie"],
+         standard_df["match_words"],
+         standard_df["new_words"],
+         standard_df["review_words"]) = zip(*standard_df["result_json"].parallel_apply(self._parse_result_json))
+        standard_df.drop(columns=["result_json"])
         self.df = standard_df
         self.df_no_trie = standard_df[["example", "label", "type", "predict_label", "predict_type"]]
         self.df_trie = standard_df[["example", "label", "type", "predict_label_trie", "predict_type_trie"]]
         self.df_trie.columns = ["example", "label", "type", "predict_label", "predict_type"]
 
+        # self.__parse_result_json(standard_df)
+
+    def _parse_result_json(self, x: str):
+        x = x.replace("'", '"')
+        a = json.loads(x)
+        results = a['results'][0]
+        _match_words = results['matched_words']
+        _new_words = results['new_words']
+        _review_words = results['review_words']
+        predict_type = self._get_result_type(_match_words + _new_words)
+        predict_label = "Pass" if predict_type == "其他" else "Reject"
+        predict_type_trie = "政治" if self._get_result_type(_review_words) == "政治" else predict_type
+        predict_label_trie = "Pass" if predict_type_trie == "其他" else "Reject"
+
+        return (predict_label, predict_type, predict_label_trie, predict_type_trie,
+                " ".join([x["word"] for x in _match_words]),
+                " ".join([x["word"] for x in _new_words]),
+                " ".join([x["word"] for x in _review_words]))
+
+    # def __parse_result_json(self, standard_df: pd.DataFrame):
+    #
+    #     result = []
+    #
+    #     _iter = standard_df.result_json
+    #     for line in _iter:
+    #         a = eval(line)
+    #         results = a['results'][0]
+    #         _match_words = results['matched_words']
+    #         _new_words = results['new_words']
+    #         _review_words = results['review_words']
+    #         predict_type = self._get_result_type(_match_words + _new_words)
+    #         predict_label = "Pass" if predict_type == "其他" else "Reject"
+    #         predict_type_trie = "政治" if self._get_result_type(_review_words) == "政治" else predict_type
+    #         predict_label_trie = "Pass" if predict_type_trie == "其他" else "Reject"
+    #         result.append([predict_label, predict_type, predict_label_trie, predict_type_trie,
+    #                        " ".join([x["word"] for x in _match_words]), " ".join([x["word"] for x in _new_words]),
+    #                        " ".join([x["word"] for x in _review_words])])
+    #
+    #     result = np.array(result)
+    #     if 'res_json' in standard_df.columns:
+    #         standard_df.drop(columns=['res_json'])
+    #     standard_df["predict_label"] = pd.Series(result[:, 0])
+    #     standard_df["predict_type"] = pd.Series(result[:, 1])
+    #     standard_df["predict_label_trie"] = pd.Series(result[:, 2])
+    #     standard_df["predict_type_trie"] = pd.Series(result[:, 3])
+    #     standard_df["match_words"] = pd.Series(result[:, 4])
+    #     standard_df["new_words"] = pd.Series(result[:, 5])
+    #     standard_df["review_words"] = pd.Series(result[:, 6])
+    #     self.df = standard_df
+    #     self.df_no_trie = standard_df[["example", "label", "type", "predict_label", "predict_type"]]
+    #     self.df_trie = standard_df[["example", "label", "type", "predict_label_trie", "predict_type_trie"]]
+    #     self.df_trie.columns = ["example", "label", "type", "predict_label", "predict_type"]
+
     def __count_f1(self):
         for category in self.indicator["no_trie"]["precision"]:
             self.indicator["no_trie"]["f1"][category] = self.f1(self.indicator["no_trie"]["precision"][category][0],
@@ -153,3 +188,8 @@ class WhisperStatistics(Statistics):
         if "Adv" in tag_set:
             return en_zh["Adv"]
         return en_zh["Normal"]
+
+
+if __name__ == '__main__':
+    ws = WhisperStatistics(
+        result_file="/home/geb/PycharmProjects/whisper-evaluate/test_data/standard-whisper-result.csv")
